import { useState } from 'react';

type SeverityType = 'success' | 'error' | 'info' | 'warning';

interface ToastState {
  open: boolean;
  message: string;
  severity: SeverityType;
}

interface ToastActions {
  handleOpen: (toastMessage: string, toastSeverity: SeverityType) => void;
  handleClose: () => void;
}

type Toast = ToastState & ToastActions;

const useToast = (): Toast => {
  const [state, setState] = useState<ToastState>({
    open: false,
    message: '',
    severity: 'success',
  });

  const handleOpen = (toastMessage: string, toastSeverity: SeverityType) => {
    setState({
      open: true,
      message: toastMessage,
      severity: toastSeverity,
    });
  };

  const handleClose = () => {
    setState({
      ...state,
      open: false,
    });
  };

  return { ...state, handleOpen, handleClose };
};

export default useToast;
